@@ -305,7 +305,7 @@
 #if !defined(SPICE_ENDIAN) && defined(_MSC_VER)
 /* Windows support only little endian arm */
 #  if defined(_M_IX86) || defined(_M_AMD64) || defined(_M_X64) \
-      || defined(_M_ARM)
+      || defined(_M_ARM) || defined(_M_ARM64)
 #    define SPICE_ENDIAN SPICE_ENDIAN_LITTLE
 #  endif
 #endif
